2. Installation — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »

# 2. Installation

The following dependencies are needed:

- Python 2.6.7 or Python 2.7.3: http://www.python.org/
- PyQt: http://www.riverbankcomputing.co.uk/

To install Umbra from the Python Package Index you can issue this command in a shell:

    pip install Umbra

or this alternative command:

    easy_install Umbra

Alternatively, if you want to directly install from Github source repository:

    git clone git://github.com/KelSolaar/Umbra.git
    cd Umbra
    python setup.py install

If you want to build the documentation you will also need:

- Tidy http://tidy.sourceforge.net/

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »